@@ -1,4 +1,5 @@
 from faststream_stomp.broker import StompBroker
+from faststream_stomp.models import StompPublishCommand, StompStreamMessage
 from faststream_stomp.publisher import StompPublisher
 from faststream_stomp.router import StompRoute, StompRoutePublisher, StompRouter
 from faststream_stomp.subscriber import StompSubscriber
@@ -6,10 +7,12 @@ from faststream_stomp.testing import TestStompBroker
 
 __all__ = [
     "StompBroker",
+    "StompPublishCommand",
     "StompPublisher",
     "StompRoute",
     "StompRoutePublisher",
     "StompRouter",
+    "StompStreamMessage",
     "StompSubscriber",
     "TestStompBroker",
 ]
